@@ -16,6 +16,11 @@ pub fn input(output: &str) -> String {
     input
 }
 
+pub fn input_trim(output: &str) -> String {
+    let str = input(output);
+    str.trim().to_string()
+}
+
 /// input with the given type, crashes if failed to convert
 pub fn input_other<T>(output: &str) -> T
 where
